package com.ruoyi.web.controller.brewery;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.brewery.domain.WyBeerReview;
import com.ruoyi.brewery.service.IWyBeerReviewService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 酒评Controller
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
@Api(tags = "酒评")
@RestController
@RequestMapping("/system/brewery/review")
public class WyBeerReviewController extends BaseController
{
    @Autowired
    private IWyBeerReviewService wyBeerReviewService;

    /**
     * 查询酒评列表
     */
    @ApiOperation("查询酒评列表")
    @PreAuthorize("@ss.hasPermi('brewery:review:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBeerReview wyBeerReview)
    {
        startPage();
        List<WyBeerReview> list = wyBeerReviewService.selectWyBeerReviewList(wyBeerReview);
        return getDataTable(list);
    }

    /**
     * 导出酒评列表
     */
    @ApiOperation("导出酒评列表")
    @PreAuthorize("@ss.hasPermi('brewery:review:export')")
    @Log(title = "酒评", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBeerReview wyBeerReview)
    {
        List<WyBeerReview> list = wyBeerReviewService.selectWyBeerReviewList(wyBeerReview);
        ExcelUtil<WyBeerReview> util = new ExcelUtil<WyBeerReview>(WyBeerReview.class);
        util.exportExcel(response, list, "酒评数据");
    }

    /**
     * 获取酒评详细信息
     */
    @ApiOperation("获取酒评详细信息")
    @PreAuthorize("@ss.hasPermi('brewery:review:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wyBeerReviewService.selectWyBeerReviewById(id));
    }

    /**
     * 新增酒评
     */
    @ApiOperation("新增酒评")
    @PreAuthorize("@ss.hasPermi('brewery:review:add')")
    @Log(title = "酒评", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WyBeerReview wyBeerReview)
    {
        return toAjax(wyBeerReviewService.insertWyBeerReview(wyBeerReview));
    }

    /**
     * 修改酒评
     */
    @ApiOperation("修改酒评")
    @PreAuthorize("@ss.hasPermi('brewery:review:edit')")
    @Log(title = "酒评", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyBeerReview wyBeerReview)
    {
        return toAjax(wyBeerReviewService.updateWyBeerReview(wyBeerReview));
    }

    /**
     * 删除酒评
     */
    @ApiOperation("删除酒评")
    @PreAuthorize("@ss.hasPermi('brewery:review:remove')")
    @Log(title = "酒评", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wyBeerReviewService.deleteWyBeerReviewByIds(ids));
    }
}
